@@ -94,6 +94,7 @@ class Client(object):
         self.connection_transports = None
         self.connection_namespaces = None
         self.socketio_path = None
+        self.sid = None
 
         self.namespaces = []
         self.handlers = {}
@@ -150,6 +151,41 @@ class Client(object):
             return set_handler
         set_handler(handler)
 
+    def event(self, *args, **kwargs):
+        """Decorator to register an event handler.
+
+        This is a simplified version of the ``on()`` method that takes the
+        event name from the decorated function.
+
+        Example usage::
+
+            @sio.event
+            def my_event(data):
+                print('Received data: ', data)
+
+        The above example is equivalent to::
+
+            @sio.on('my_event')
+            def my_event(data):
+                print('Received data: ', data)
+
+        A custom namespace can be given as an argument to the decorator::
+
+            @sio.event(namespace='/test')
+            def my_event(data):
+                print('Received data: ', data)
+        """
+        if len(args) == 1 and len(kwargs) == 0 and callable(args[0]):
+            # the decorator was invoked without arguments
+            # args[0] is the decorated function
+            return self.on(args[0].__name__)(args[0])
+        else:
+            # the decorator was invoked with arguments
+            def set_handler(handler):
+                return self.on(handler.__name__, *args, **kwargs)(handler)
+
+            return set_handler
+
     def register_namespace(self, namespace_handler):
         """Register a namespace handler object.
 
@@ -314,7 +350,7 @@ class Client(object):
             raise exceptions.TimeoutError()
         return callback_args[0] if len(callback_args[0]) > 1 \
             else callback_args[0][0] if len(callback_args[0]) == 1 \
-                else None
+            else None
 
     def disconnect(self):
         """Disconnect from the server."""
@@ -481,9 +517,10 @@ class Client(object):
                     'Maximum reconnection attempts reached, giving up')
                 break
 
-    def _handle_eio_connect(self):  # pragma: no cover
+    def _handle_eio_connect(self):
         """Handle the Engine.IO connection event."""
         self.logger.info('Engine.IO connection established')
+        self.sid = self.eio.sid
 
     def _handle_eio_message(self, data):
         """Dispatch Engine.IO messages."""
@@ -521,6 +558,7 @@ class Client(object):
         self._trigger_event('disconnect', namespace='/')
         self.callbacks = {}
         self._binary_packet = None
+        self.sid = None
         if self.eio.state == 'connected' and self.reconnection:
             self._reconnect_task = self.start_background_task(
                 self._handle_reconnect)
